@@ -2,11 +2,11 @@ from .dataset import Dataset
 from .single_cell_labeled import SingleCellLabeledDataset
 from .single_cell_perturbation import SingleCellPerturbationDataset
 from .types import Organism
-from .utils import list_available_datasets, load_dataset, load_local_dataset
+from .utils import list_available_datasets, load_dataset, load_custom_dataset
 
 __all__ = [
     "load_dataset",
-    "load_local_dataset",
+    "load_custom_dataset",
     "list_available_datasets",
     "SingleCellLabeledDataset",
     "SingleCellPerturbationDataset",
