@@ -1,8 +1,13 @@
-from .cross_species import (
+from .cross_species_integration import (
     CrossSpeciesIntegrationOutput,
     CrossSpeciesIntegrationTask,
     CrossSpeciesIntegrationTaskInput,
 )
+from .cross_species_label_prediction import (
+    CrossSpeciesLabelPredictionTaskInput,
+    CrossSpeciesLabelPredictionOutput,
+    CrossSpeciesLabelPredictionTask,
+)
 from .perturbation_expression_prediction import (
     PerturbationExpressionPredictionOutput,
     PerturbationExpressionPredictionTask,
@@ -13,6 +18,9 @@ __all__ = [
     "CrossSpeciesIntegrationTaskInput",
     "CrossSpeciesIntegrationOutput",
     "CrossSpeciesIntegrationTask",
+    "CrossSpeciesLabelPredictionTaskInput",
+    "CrossSpeciesLabelPredictionOutput",
+    "CrossSpeciesLabelPredictionTask",
     "PerturbationExpressionPredictionTask",
     "PerturbationExpressionPredictionTaskInput",
     "PerturbationExpressionPredictionOutput",
